@@ -44,6 +44,7 @@ sub parse{
                 CVV             => $7,
             };
         }
+        $self->{ tracks }[0] = $track1;
     }
     #track2
     if( $stripe =~ /\;[\w\^]+\?\n/ and ( length $& < 39 ) ){  # stripe...
@@ -60,6 +61,7 @@ sub parse{
                 CVV             => $5,
             };
         }
+        $self->{ tracks }[1] = $track2;
     }
     #track3
     if( $stripe =~ /\;[\w\^]+\?\n/ ){
@@ -110,9 +112,25 @@ sub parse{
                 CRYPTO_CHECK    => $+{cryptocheck},
            };
         }
+        $self->{ tracks }[2] = $track3;
     }
 }
 
+sub track1 {
+    my ( $self ) = @_;
+    return defined $self->{ tracks }[ 0 ]? $self->{ tracks }[ 0 ] : undef;
+}
+
+sub track2 {
+    my ( $self ) = @_;
+    return defined $self->{ tracks }[ 1 ]? $self->{ tracks }[ 1 ] : undef;
+}
+
+sub track3 {
+    my ( $self ) = @_;
+    return defined $self->{ tracks }[ 2 ]? $self->{ tracks }[ 2 ] : undef;
+}
+
 1;
 
 __END__
@@ -127,7 +145,7 @@ Card::Magnetic - Magnetic Stripe parser
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -146,7 +164,7 @@ Is also possible have cards that has only the track 1 and 2, 2 and 3 or any comb
 
 =head1 NAME
 
-Card::Magnetic - Magnetic stripe parser and builder
+Card::Magnetic - Magnetic stripe parser
 
 =head1 SUBROUTINES/METHODS
 
@@ -164,11 +182,24 @@ Parse the stripe and create a internal hash hashref structure with the exploded
 
     {
         stripe => "full stripe content",
+        tracks => [ ], #array with the tracks on the strip
         track1 => { }, # hash with the fields on track 1
         track2 => { }, # Same as track 1, will have a hash with the track2 fields
         track3 => { }, # Track3 
     }
 
+=head2 track1
+
+Return the string of the track, 
+
+=head2 track2
+
+Return the string of the track, 
+
+=head2 track3
+
+Return the string of the track, 
+
 =head1 AUTHOR
 
 Frederico Recsky <recsky@cpan.org>
@@ -197,7 +228,7 @@ Frederico Recsky <cartas@frederico.me>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Frederico Recsky.
+This software is copyright (c) 2017 by Frederico Recsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
